---
title: 크로스보더(Cross-border) 서비스 안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
seo:
  title: 크로스보더 서비스 안내
  description: >-
    해외 현지에 특화 결제서비스인 포트원의 크로스보더를 소개합니다. 여러 국가의 고객에게 온라인 결제를 한 번에 제공하며, 현지 법인 설립
    없이도 해외 고객으로부터 결제를 받을 수 있다는 큰 장점을 가지고 있습니다.
  keywords:
    - 해외결제
    - 크로스보더
tags:
  - 해외결제
  - 크로스보더
pgCompanies:
  - 공통
searchTags:
  - 글로벌
  - Cross broder
  - 해외결제
  - 크로스보더
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="해외 현지에 특화된 결제서비스인 포트원의 크로스보더(Cross-border) 서비스를 안내드립니다" />

### **서비스 소개**

- Cross-border 서비스는 한 번에 여러 국가의 고객에게 온라인결제를 제공할 수 있는 결제솔루션입니다.
- 일반적인 해외결제와 다르게 현지 법인 설립 없이도 해외 고객으로부터 결제를 받을 수 있다는 것이 가장 큰 장점입니다.

### **서비스 특징**

- 신용카드, 현지 간편결제, 계좌이체, QR Code결제 등 국가별 고객이 선호하는 다양한 결제수단을 제공합니다
- 결제서비스 제공 국가의 언어, 화폐, 관세가 적용된 결제창을 제공합니다.

### **이용 절차**



**1. 도입문의 제출**

- 해외 결제 서비스 ‘이용 예정 국가’ 및 ‘결제수단’, ‘해외 월 거래액’을 작성하여 제출합니다. 국가별 지원 결제수단 가이드를 참고해주세요. (ex : 베트남/ZaloPay, 인도네시아/LinkAja/Dana, 1억/10만달러 이상)



<Callout icon="" title="도입문의 바로가기" content=" " />

**2. 온보딩 안내**

- 포트원 전문 상담사가 최적의 결제사와 결제수단을 제안 드립니다. (신청 후 약 1영업일 내)

<Highlight text="크로스보더" />

- 현지 법인 없이 해외결제를 이용해야 하는 기업
- 카드 결제를 보편적으로 사용하지 않는 국가의 현지 결제수단으로 결제가 필요한 형태
- 지원 국가 및 PG사 : 아래의 국가별 지원 결제수단 가이드 참고

<Highlight text="일반 해외 결제" />

- 포트원 코리아\_전자결제(PG) 서비스 신청 절차 진행
- 해외 카드(해외VISA/MASTER/JCB/AMEX/DINERS) 수단 제공 서비스
- 지원 PG사 : 페이팔/ 엑심베이 / 페이먼트월
- 참고 :  [일반 해외결제 전자결제 신청방법 보러가기↗](https://help.portone.io/category/procedure/pg-application)

**3. 이용계약서 작성 및 KYC 심사 진행**

- PSP(결제수단제공업체) 계약 및 KYC(고객본인확인제도) 심사용 사업자 기본정보 작성하여 아래 제출처로 제출합니다. 제출된 서류는 포트원 코리아(KR) 온보딩 담당자가 ‘KYC 심사’ 하여 포트원 글로벌 가입절차와 연동방법을 안내 드립니다.
- **제출처 : <onboarding@portone.io>**

<Callout content="**KYC** **전** **운영** **사이트** **내** **필수** **요건**

1. 상품 등록 필수
2. 배송 정책 명시
3. 취소 및 환불 정책 명시
4. 주문(결제)페이지와 결제 기능 구현" title="참고사항" icon="💡" />

**4. 글로벌 콘솔 가입 및 테스트환경 연동**

글로벌 콘솔(Admin Portal) 가입 후 테스트 연동을 위한 [포트원 글로벌 콘솔 ↗](https://admin.portone.cloud/)(Admin Portal) 채널(PSP) 정보 설정한 뒤 결제 테스트 진행

<Callout title="글로벌 관리자콘솔 이용 방법 보러가기 ↗" icon="" content="" />

**5. 실 운영환경 연동**

- 포트원 코리아 담당자’가 실운영용 ‘결제 ID’ 및 ‘연동키’를 발급하여 안내드리면 연동키를 활용하여\
  [포트원 글로벌 콘솔 ↗](https://admin.portone.cloud/) 내 실 운영용 채널(PG)정보를 설정하여 연동을 진행합니다.
- 결제 ID는 KYC 심사 완료 후 발급됩니다.

**6. 서비스 오픈**

- 연동 및 충분한 내부 테스트 후 서비스를 오픈해주세요.

### **크로스보더 와 일반 해외결제 비교**

<Callout title="크로스보더와 해외결제는 다음과 같은 차이점이 있습니다." />

1. **크로스보더**

- 현지 법인 없이 해외결제를 이용해야 하는 기업
- 카드 결제를 보편적으로 사용하지 않는 국가의 현지 결제수단으로 결제가 필요한 형태
- 지원 국가 및 PG사 : 아래의 국가별 지원 결제수단 가이드 참고

**2. 일반 해외 결제**

- 포트원 코리아 전자결제(PG) 서비스 신청 절차 진행
- 해외 카드(해외VISA/MASTER/JCB/AMEX/DINERS) 수단 제공 서비스
- 지원 PG사 : 페이팔/ 엑심베이 / 페이먼트월

**💡 그럼 왜 크로스보더를 이용해야할까요?**

- 크로스보더 서비스는 다음과 같은 특장점이 존재합니다.



### **국가별 지원 결제수단**

Payment channel이 PG사일 경우, Payment Method에 간편결제사가 적용 될 수 있습니다.

- Payment channels : 결제 제공사
- Payment Methods : 결제수단
- Payment Method Key : 결제수단 코드 (연동시 사용)

<Callout title="크로스보더 서비스 지원 결제수단 보러가기 ↗" />



### **연동 가이드**

- 연동 가이드는 영문으로 제공되고 있으며 연동 시 궁금하신 점은 포트원 기술지원팀(<support@portone.io>)을 통하여 문의주시기 바랍니다.

<Callout icon="" title="크로스보더 연동 개발가이드 보러가기 ↗" />
